[xorg-commit-diffs] xc/programs/Xserver/hw/darwin/quartz_1.3 Imakefile, 1.1.4.2, 1.1.4.3 rootlessAquaGlue.c, 1.1.4.2, 1.1.4.3 rootlessAquaImp.m, 1.1.4.2, 1.1.4.3 rootlessValTree.c, 1.1.4.3, 1.1.4.4

Egbert Eich xorg-commit at pdx.freedesktop.org
Thu Apr 15 03:16:01 PDT 2004


Committed by: eich

Update of /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz_1.3
In directory pdx:/home/eich/tstbuild/xc/programs/Xserver/hw/darwin/quartz_1.3

Modified Files:
      Tag: XORG-CURRENT
	Imakefile rootlessAquaGlue.c rootlessAquaImp.m 
	rootlessValTree.c 
Log Message:
2004-04-15  Egbert Eich  <eich at freedesktop.org>
        Merged changes from RELEASE-1 branch
	


Index: Imakefile
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz_1.3/Imakefile,v
retrieving revision 1.1.4.2
retrieving revision 1.1.4.3
diff -u -d -r1.1.4.2 -r1.1.4.3
--- a/Imakefile	5 Mar 2004 13:40:00 -0000	1.1.4.2
+++ b/Imakefile	15 Apr 2004 10:15:57 -0000	1.1.4.3
@@ -21,8 +21,8 @@
 LinkSourceFile(quartzPasteboard.c,../quartz)
 LinkSourceFile(quartzPasteboard.h,../quartz)
 LinkSourceFile(quartzShared.h,../quartz)
-LinkSourceFile(pseudorama.c,../quartz)
-LinkSourceFile(pseudorama.h,../quartz)
+LinkSourceFile(pseudoramiX.c,../quartz)
+LinkSourceFile(pseudoramiX.h,../quartz)
 LinkSourceFile(quartzStartup.c,../quartz)
 LinkSourceFile(XDarwinStartup.c,../quartz)
 LinkSourceFile(XDarwinStartup.man,../quartz)
@@ -45,7 +45,7 @@
         rootlessScreen.c \
         rootlessValTree.c \
         rootlessWindow.c \
-        pseudorama.c
+        pseudoramiX.c
 
 OBJS =  Preferences.o \
         XApplication.o \
@@ -65,7 +65,7 @@
         rootlessScreen.o \
         rootlessValTree.o \
         rootlessWindow.o \
-        pseudorama.o
+        pseudoramiX.o
 
 INCLUDES = -I. -I$(SERVERSRC)/fb -I$(SERVERSRC)/mi -I$(SERVERSRC)/include \
            -I$(XINCLUDESRC) -I$(FONTINCSRC) -I$(SERVERSRC)/render \

Index: rootlessAquaGlue.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz_1.3/rootlessAquaGlue.c,v
retrieving revision 1.1.4.2
retrieving revision 1.1.4.3
diff -u -d -r1.1.4.2 -r1.1.4.3
--- a/rootlessAquaGlue.c	5 Mar 2004 13:40:00 -0000	1.1.4.2
+++ b/rootlessAquaGlue.c	15 Apr 2004 10:15:57 -0000	1.1.4.3
@@ -209,7 +209,7 @@
 
     // This X11 screen covers all CoreGraphics displays we just found.
     // If there's more than one CG display, then video mirroring is on
-    // or Pseudorama is on.
+    // or PseudoramiX is on.
     displayInfo->displayCount = allocatedDisplays;
     displayInfo->displayIDs = displays;
 

Index: rootlessValTree.c
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz_1.3/rootlessValTree.c,v
retrieving revision 1.1.4.3
retrieving revision 1.1.4.4
diff -u -d -r1.1.4.3 -r1.1.4.4
--- a/rootlessValTree.c	7 Mar 2004 23:45:10 -0000	1.1.4.3
+++ b/rootlessValTree.c	15 Apr 2004 10:15:57 -0000	1.1.4.4
@@ -1,3 +1,4 @@
+/* $XdotOrg$ */
 /*
  * Calculate window clip lists for rootless mode
  *
@@ -81,6 +82,32 @@
 Equipment Corporation.
 
 ******************************************************************/
+
+Copyright (c) 1991, 1997 Digital Equipment Corporation, Maynard, Massachusetts.
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software.
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
+DIGITAL EQUIPMENT CORPORATION BE LIABLE FOR ANY CLAIM, DAMAGES, INCLUDING,
+BUT NOT LIMITED TO CONSEQUENTIAL OR INCIDENTAL DAMAGES, OR OTHER LIABILITY,
+WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
+IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of Digital Equipment Corporation
+shall not be used in advertising or otherwise to promote the sale, use or other
+dealings in this Software without prior written authorization from Digital
+Equipment Corporation.
+
+******************************************************************/
  /* 
   * Aug '86: Susan Angebranndt -- original code
   * July '87: Adam de Boor -- substantially modified and commented




More information about the xorg-commit-diffs mailing list
Index: rootlessAquaImp.m
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz_1.3/rootlessAquaImp.m,v
retrieving revision 1.1.4.2
retrieving revision 1.1.4.3
diff -u -d -r1.1.4.2 -r1.1.4.3
--- a/rootlessAquaImp.m	5 Mar 2004 13:40:00 -0000	1.1.4.2
+++ b/rootlessAquaImp.m	15 Apr 2004 10:15:57 -0000	1.1.4.3
@@ -8,7 +8,7 @@
 #include "XWindow.h"
 #include "fakeBoxRec.h"
 #include "quartzCommon.h"
-#include "pseudorama.h"
+#include "pseudoramiX.h"
 
 extern void ErrorF(const char *, ...);
 
@@ -20,18 +20,18 @@
 #define WINREC(rw) ((AquaWindowRec *)rw)
 
 
 // Multihead note: When rootless mode uses Pseudorama, the
 // X server only sees one screen; only Pseudorama itself knows
 // about all of the screens.
 
 int AquaDisplayCount()
 {
     aquaNumScreens = [[NSScreen screens] count];
 
-    if (noPseudoramaExtension) {
+    if (noPseudoramiXExtension) {
         return aquaNumScreens;
     } else {
-        return 1; // only Pseudorama knows about the rest
+        return 1; // only PseudoramiX knows about the rest
     }
 }
 
@@ -43,7 +43,7 @@
     *spp = 3;
     *bpp = 32;
 
-    if (noPseudoramaExtension) {
+    if (noPseudoramiXExtension) {
         NSScreen *screen = [[NSScreen screens] objectAtIndex:index];
         NSRect frame = [screen frame];
 
@@ -87,7 +87,7 @@
         *height = unionRect.size.height;
         *rowBytes = (*width) * (*bpp) / 8;
 
         // Tell Pseudorama about the real screens.
         // InitOutput() will move the big screen to (0,0),
         // so compensate for that here.
         for (i = 0; i < [screens count]; i++) {
@@ -98,7 +98,7 @@
             // Skip this screen if it's a mirrored copy of an earlier screen.
             for (j = 0; j < i; j++) {
                 if (NSEqualRects(frame, [[screens objectAtIndex:j] frame])) {
-                    ErrorF("Pseudorama screen %d is a mirror of screen %d.\n",
+                    ErrorF("PseudoramiX screen %d is a mirror of screen %d.\n",
                            i, j);
                     break;
                 }
@@ -113,17 +113,17 @@
                 frame.size.height -= aquaMenuBarHeight;
             }
 
-            ErrorF("Pseudorama screen %d added: %dx%d @ (%d,%d).\n", i,
+            ErrorF("PseudoramiX screen %d added: %dx%d @ (%d,%d).\n", i,
                    (int)frame.size.width, (int)frame.size.height,
                    (int)frame.origin.x, (int)frame.origin.y);
 
             frame.origin.x -= unionRect.origin.x;
             frame.origin.y -= unionRect.origin.y;
 
-            ErrorF("Pseudorama screen %d placed at X11 coordinate (%d,%d).\n",
+            ErrorF("PseudoramiX screen %d placed at X11 coordinate (%d,%d).\n",
                    i, (int)frame.origin.x, (int)frame.origin.y);
 
-            PseudoramaAddScreen(frame.origin.x, frame.origin.y,
+            PseudoramiXAddScreen(frame.origin.x, frame.origin.y,
                                  frame.size.width, frame.size.height);
         }
     }
@@ -20,18 +20,18 @@
 
 
-// Multihead note: When rootless mode uses Pseudorama, the
-// X server only sees one screen; only Pseudorama itself knows
+// Multihead note: When rootless mode uses PseudoramiX, the
+// X server only sees one screen; only PseudoramiX itself knows
 // about all of the screens.
 
@@ -87,7 +87,7 @@
         *rowBytes = (*width) * (*bpp) / 8;
 
-        // Tell Pseudorama about the real screens.
+        // Tell PseudoramiX about the real screens.
         // InitOutput() will move the big screen to (0,0),
         // so compensate for that here.
